<article class="post">
  <header class="post-header">
    <h1 class="post-title">{{title}}</h1>
    <div class="post-meta">
      <time class="post-date">{{date}}</time>
      <span class="reading-time">{{reading-time}}</span>
    </div>
    <div class="grimoire-tags">{{tags}}</div>
  </header>
  <div class="content">
    {{content}}
  </div>
</article>
