<li class="post-item">
  <a class="post-item-title" href="{{url}}">{{title}}</a>
  <span class="post-item-meta">
    <time class="post-item-date">{{date}}</time>
    <span class="post-item-tags">{{tags}}</span>
  </span>
</li>
